@@ -3,7 +3,7 @@ our $AUTHORITY = 'cpan:GENE';
 
 # ABSTRACT: Compute Halstead complexity metrics
 
-our $VERSION = '0.0201';
+our $VERSION = '0.0202';
 
 use Moo;
 use strictures 2;
@@ -19,34 +19,30 @@ has file => (
 );
 
 
-has n_operators => (
+has [qw(
+    n_operators
+    n_operands
+    n_distinct_operators
+    n_distinct_operands
+)] => (
     is       => 'ro',
     init_arg => undef,
 );
 
 
-has n_operands => (
-    is       => 'ro',
+has [qw(
+    prog_vocab
+    prog_length
+    est_prog_length
+    volume
+    difficulty
+    level
+    effort
+    time_to_program
+    delivered_bugs
+)] => (
+    is       => 'lazy',
     init_arg => undef,
-);
-
-
-has n_distinct_operators => (
-    is       => 'ro',
-    init_arg => undef,
-);
-
-
-has n_distinct_operands => (
-    is       => 'ro',
-    init_arg => undef,
-);
-
-
-has prog_vocab => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
     builder  => 1,
 );
 
@@ -55,107 +51,43 @@ sub _build_prog_vocab {
     return $self->n_distinct_operators + $self->n_distinct_operands;
 }
 
-
-has prog_length => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_prog_length {
     my ($self) = @_;
     return $self->n_operators + $self->n_operands;
 }
 
-
-has est_prog_length => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_est_prog_length {
     my ($self) = @_;
     return $self->n_distinct_operators * _log2($self->n_distinct_operators)
         + $self->n_distinct_operands * _log2($self->n_distinct_operands);
 }
 
-
-has volume => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_volume {
     my ($self) = @_;
     return $self->prog_length * _log2($self->prog_vocab);
 }
 
-
-has difficulty => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_difficulty {
     my ($self) = @_;
     return ($self->n_distinct_operators / 2)
         * ($self->n_operands / $self->n_distinct_operands);
 }
 
-
-has level => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_level {
     my ($self) = @_;
     return 1 / $self->difficulty;
 }
 
-
-has effort => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_effort {
     my ($self) = @_;
     return $self->difficulty * $self->volume;
 }
 
-
-has time_to_program => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_time_to_program {
     my ($self) = @_;
     return $self->effort / 18; # seconds
 }
 
-
-has delivered_bugs => (
-    is       => 'ro',
-    init_arg => undef,
-    lazy     => 1,
-    builder  => 1,
-);
-
 sub _build_delivered_bugs {
     my ($self) = @_;
     return ($self->effort ** (2/3)) / 3000;
@@ -252,7 +184,7 @@ Perl::Metrics::Halstead - Compute Halstead complexity metrics
 
 =head1 VERSION
 
-version 0.0201
+version 0.0202
 
 =head1 SYNOPSIS
 
